"use strict";

exports.__esModule = true;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var GatewayRegistry = (function () {
  function GatewayRegistry() {
    _classCallCheck(this, GatewayRegistry);

    this._containers = {};
    this._children = {};
  }

  GatewayRegistry.prototype._renderContainer = function _renderContainer(name) {
    if (!this._containers[name]) {
      return;
    }

    this._containers[name].setState({
      children: this._children[name]
    });
  };

  GatewayRegistry.prototype._cleanupContainer = function _cleanupContainer(name) {
    this._containers[name].setState({
      children: []
    });
  };

  GatewayRegistry.prototype.addContainer = function addContainer(name, container) {
    this._containers[name] = container;
    this._renderContainer(name);
  };

  GatewayRegistry.prototype.removeContainer = function removeContainer(name, container) {
    this._containers[name] = null;
    this._cleanupContainer(name);
  };

  GatewayRegistry.prototype.addChild = function addChild(name, child) {
    if (!this._children[name]) {
      this._children[name] = [];
    }

    this._children[name] = this._children[name].concat(child);
    this._renderContainer(name);
  };

  GatewayRegistry.prototype.removeChild = function removeChild(name, child) {
    this._children[name] = this._children[name].filter(function (c) {
      return c !== child;
    });
  };

  return GatewayRegistry;
})();

exports.default = GatewayRegistry;